<?php

namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\SM\Service\Sm00001000VendedorPropostaService;

class Sm00001000VendedorPropostaController extends SMCrud {
    
    protected $dataSourceName = "fct_vendedororca_widget";
    protected $vendedorPropostaService;
    
    public function __construct($crudService, $environment, Sm00001000VendedorPropostaService $vendedorPropostaService) {
        parent::__construct($crudService, $environment);
        $this->vendedorPropostaService = $vendedorPropostaService;
    }
    
    /**
     * Faz duas validações: se o vendedor a ser salvo já existe e se já existe um vendedor principal.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function validarVendedor(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $nrvendedororca = $row["NRVENDEDORORCA"];
            $nrparcvendedor = $row["NRPARCVENDEDOR"];
            
            $existeVendedor = $this->vendedorPropostaService->validarSeExisteVendedor($nrseqorcamento, $nrvendedororca, $nrparcvendedor);
            $existePrincipal = $this->vendedorPropostaService->validarSeExisteVendedorPrincipal($nrseqorcamento, $nrvendedororca);
            
            $retorno = array(
                "existeVendedor"  => $existeVendedor,
                "existePrincipal" => $existePrincipal
            );
            
            $response->addDataSet(new DataSet($this->dataSourceName, $retorno));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Retorna a soma da porcentagem na participação da venda dos vendedores da proposta.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function getPorcentagemVendedores(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $nrorg          = $row["NRORG"];
            
            $porcentagem = $this->vendedorPropostaService->getPorcentagemVendedores($nrseqorcamento, $nrorg);
            $response->addDataSet(new DataSet($this->dataSourceName, array("porcentagem" => $porcentagem)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}

?>