<?php

namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class IntegracaoFmFactory {
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    /**
     * Retorna a URL de integração com o FM.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function getUrlIntegracaoFM(array $params) {
        $sql = "SELECT DSURLINTEGRACAOFM
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Verifica se o contrato utiliza a integração com o FM.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function verificarUtilizaIntegracao(array $params) {
        $sql = "SELECT IDINTEGRACAOFM, IDINTEGRALOCAISFM, IDINTEGRAMEDICAOFM
                  FROM FCT_CONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna o tipo de local para integração dos locais de atendimento.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function getTipoLocalIntegracaoFM(array $params) {
        $sql = "SELECT NRTIPOLOCALCLIFM
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    /**
     * Retorna os dados de local para integração dos locais de atendimento.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function getDadosLocais(array $params) {
        $sql = "SELECT FCT_RELACESTRUTURACONT.NRESTRUTURAM, ESTRUTURAM.NMESTRUTURAM, 
                       FCT_RELACESTRUTURACONT.NRSEQCONTRATO, CLIENTE.CDCLIENTE
                  FROM FCT_RELACESTRUTURACONT
                  JOIN ESTRUTURAM
                    ON ESTRUTURAM.NRESTRUTURAM = FCT_RELACESTRUTURACONT.NRESTRUTURAM
                  JOIN FCT_CONTRATO 
                    ON FCT_CONTRATO.NRSEQCONTRATO = FCT_RELACESTRUTURACONT.NRSEQCONTRATO
                   AND FCT_CONTRATO.NRORG = FCT_RELACESTRUTURACONT.NRORG
                  JOIN CLIENTE 
                    ON CLIENTE.NRPARCNEGOCIO = FCT_CONTRATO.NRPARCNEGOCIO
                 WHERE FCT_RELACESTRUTURACONT.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND FCT_RELACESTRUTURACONT.NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    /**
     * Retorna os dados de local para integração dos locais de atendimento.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function updateDadosMedicao(array $params) {
        $sql = "UPDATE FCT_MEDVARMEDICAOFATURA
                   SET QTMEDIDAVARIAVEL = :QTMEDIDAVARIAVEL,
                       QTMEDIDAMEDICAO  = :QTMEDIDAVARIAVEL - QTFRANQUIA,
                       DTULTATU         = SYSDATE,
                       NRORGULTATU      = :NRORG,
                       CDOPERULTATU     = :OPERADOR
                 WHERE NRMEDICAOFATURA    = :NRMEDICAOFATURA
                 AND   CDSERVORCA         = :CDSERVORCA
                 AND   CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

}
?>
